==> haskell-hspec-contrib-0.5.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-21BilfBQHboHbuUuEIG2sJ
key: hspec-contrib-0.5.0-21BilfBQHboHbuUuEIG2sJ
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 5affab8571d9b648c482ecd0b031496c
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-21BilfBQHboHbuUuEIG2sJ
depends:
    base-4.11.1.0 hspec-core-2.5.5-GQz0GZFprmixw75pGI27v
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hspec-core-2.5.5-GQz0GZFprmixw75pGI27v=2d79cfefc5f2bd4024218505e216dbe0
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-contrib
version: 0.5.0
id: hspec-contrib-0.5.0-JRo1vcyEUl3DFFrHqiA6MB
key: hspec-contrib-0.5.0-JRo1vcyEUl3DFFrHqiA6MB
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2014 Junji Hashimoto
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Contributed functionality for Hspec
description:
    Contributed functionality for Hspec
category: Testing
abi: 73a16326d1b89b458eccad685ae31d35
exposed: True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-contrib-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-contrib-0.5.0
hs-libraries: HShspec-contrib-0.5.0-JRo1vcyEUl3DFFrHqiA6MB
depends:
    base-4.11.1.0 hspec-core-2.5.5-JtKeMsWtF9L8hZENfYWIs4
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hspec-core-2.5.5-JtKeMsWtF9L8hZENfYWIs4=811312d1a0e6a2a1ce099e5ee30f15f0
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
haddock-interfaces: /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock
haddock-html: /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
